// Copyright 2022 Woodpecker Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package common

import (
	"encoding/base64"
)

func GenerateContainerConf(commands []string, goos string) (env map[string]string, entry []string, cmd string) {
	env = make(map[string]string)
	if goos == "windows" {
		env["CI_SCRIPT"] = base64.StdEncoding.EncodeToString([]byte(generateScriptWindows(commands)))
		env["HOME"] = "c:\\root"
		env["SHELL"] = "powershell.exe"
		entry = []string{"powershell", "-noprofile", "-noninteractive", "-command"}
		cmd = "[System.Text.Encoding]::UTF8.GetString([System.Convert]::FromBase64String($Env:CI_SCRIPT)) | iex"
	} else {
		env["CI_SCRIPT"] = base64.StdEncoding.EncodeToString([]byte(generateScriptPosix(commands)))
		env["HOME"] = "/root"
		env["SHELL"] = "/bin/sh"
		entry = []string{"/bin/sh", "-c"}
		cmd = "echo $CI_SCRIPT | base64 -d | /bin/sh -e"
	}

	return env, entry, cmd
}
